@@ -1,4 +1,7 @@
-from typing import TypeAlias
+"""The model module holds the GridSortModel, a type alias."""
+from typing import List
+
+from typing_extensions import TypeAlias
 
 from mui.v5.grid.sort.item import GridSortItem
 
@@ -9,4 +12,4 @@ Documentation:
 Code:
     https://github.com/mui/mui-x/blob/0cdee3369bbf6df792c9228ef55ea1a61a246ff3/packages/grid/x-data-grid/src/models/gridSortModel.ts#L44
 """
-GridSortModel: TypeAlias = list[GridSortItem]
+GridSortModel: TypeAlias = List[GridSortItem]
