@@ -2,12 +2,10 @@
 
 Meant as an equality check.
 """
-from datetime import datetime
+from datetime import date, datetime, time
 from operator import eq
 from typing import Any
 
-from sqlalchemy import Date, DateTime, Time
-
 
 def apply_is_operator(column: Any, value: Any) -> Any:
     """Handles applying the is x-data-grid operator to a column.
@@ -23,8 +21,16 @@ def apply_is_operator(column: Any, value: Any) -> Any:
     Returns:
         Any: The column after applying the is filter using the provided value.
     """
-    # TODO: convert to column.type.python_type like isNot
-    if isinstance(column.type, (DateTime, Time, Date)) and value is not None:
+    if column.type.python_type in {datetime, time, date} and value is not None:
         return eq(column, datetime.fromisoformat(value))
-    else:
-        return eq(column, value)
+    if column.type.python_type in {bool} and value is not None:
+        # "" is used to represent "any" in MUI v5
+        if value in {"", "any"}:
+            return column.in_((True, False))
+        elif value == "true":
+            return eq(column, True)
+        elif value == "false":
+            return eq(column, False)
+        else:
+            raise ValueError(f"Unexpected boolean filter value received: {value}")
+    return eq(column, value)
